--[[
	BarKeepOptions version 30000
	Further extensively customized by Platykurtic
	OneBag and BagBarShow/Hide code by Blood Druid
	This provides the command handling for BarKeep

BarKeep, a World of Warcraft addon to manage the Blizzard Bars.
Copyright (C) 2007 Platykurtic except the code which others created.

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
]]

local L = BARKEEP_LOCALE
BARKEEP_LOCALE = nil

local _G = getfenv(0)

function BarKeepOptions_OnLoad()
	this:RegisterEvent("VARIABLES_LOADED")
	this:RegisterEvent("PLAYER_ENTERING_WORLD")
	
	local Options = CreateFrame("Frame", nil, UIParent)
	Options.name = "BarKeep"
	Options:Hide()
	Options:SetScript("OnShow", function(self)

		-- Make your frames starting with the title and description frames
		local title = Options:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
		title:SetPoint("TOPLEFT", 16, -16)
		title:SetText("BarKeep")

		local subtitle = Options:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")	
		subtitle:SetHeight(32)
		subtitle:SetPoint("TOPLEFT", title, "BOTTOMLEFT", 0, -8)
		subtitle:SetPoint("RIGHT", Options, -32, 0)
		subtitle:SetNonSpaceWrap(true)
		subtitle:SetJustifyH("LEFT")
		subtitle:SetJustifyV("TOP")
		subtitle:SetText(L["This allows you to set all the options for how BarKeep will manage the Action Bars."])

		-- BarKeep Lock/Unlock
		local locktoggle = CreateFrame("CheckButton", ("BarKeep_Locked"), Options,"OptionsCheckButtonTemplate")
		getglobal(locktoggle:GetName() .. "Text"):SetText(L["BarKeep Locked"])
		getglobal(locktoggle:GetName() .. "Text"):SetFontObject(GameFontNormalSmall)
		locktoggle:SetChecked(BK_Setting.Locked)
		locktoggle:SetScript("OnClick", function()
			-- Check whether locked or not
			if BK_Setting.Locked then BarKeepOptions_UnLock() else BarKeepOptions_Lock() end
		end)
		locktoggle:SetPoint("TOPLEFT", subtitle, "BOTTOMLEFT",0,10)

		--MenuBar and ShapeBar
		local menutoggle = CreateFrame("CheckButton", ("BarKeep_MenuBarHide"), Options,"OptionsCheckButtonTemplate")
		getglobal(menutoggle:GetName() .. "Text"):SetText(L["MicroBar Hidden"])
		getglobal(menutoggle:GetName() .. "Text"):SetFontObject(GameFontNormalSmall)
		menutoggle:SetChecked(BK_Setting.MenuBarHide)
		menutoggle:SetScript("OnClick", function()
			-- Check whether hidden or not
			if BK_Setting.MenuBarHide then BarKeepOptions_ShowMenuBar() else BarKeepOptions_HideMenuBar() end
		end)
		menutoggle:SetPoint("TOPLEFT", locktoggle, "BOTTOMLEFT",0,10)
		
		local shapetoggle = CreateFrame("CheckButton", ("BarKeep_ShapeBarHide"), Options,"OptionsCheckButtonTemplate")
		getglobal(shapetoggle:GetName() .. "Text"):SetText(L["StanceBar Hidden"])
		getglobal(shapetoggle:GetName() .. "Text"):SetFontObject(GameFontNormalSmall)
		shapetoggle:SetChecked(BK_Setting.ShapeBarHide)
		shapetoggle:SetScript("OnClick", function()
			-- Check whether hidden or not
			if BK_Setting.ShapeBarHide then BarKeepOptions_ShowShapeBar() else BarKeepOptions_HideShapeBar() end
		end)
		shapetoggle:SetPoint("LEFT", menutoggle, "RIGHT",90,0)
		
		-- Bag Bar options
		local bagtoggle = CreateFrame("CheckButton", ("BarKeep_BagBarHide"), Options,"OptionsCheckButtonTemplate")
		getglobal(bagtoggle:GetName() .. "Text"):SetText(L["BagBar Hidden"])
		getglobal(bagtoggle:GetName() .. "Text"):SetFontObject(GameFontNormalSmall)
		bagtoggle:SetChecked(BK_Setting.BagBarHide)
		bagtoggle:SetScript("OnClick", function()
			-- Check whether hidden or not
			if BK_Setting.BagBarHide then BarKeepOptions_BagBarShowHide(false) else BarKeepOptions_BagBarShowHide(true) end
		end)
		bagtoggle:SetPoint("TOPLEFT", menutoggle, "BOTTOMLEFT",0,10)

		local bagonebag = CreateFrame("CheckButton", ("BarKeep_BagBarOneBag"), Options,"OptionsCheckButtonTemplate")
		getglobal(bagonebag:GetName() .. "Text"):SetText(L["BagBar OneBag"])
		getglobal(bagonebag:GetName() .. "Text"):SetFontObject(GameFontNormalSmall)
		bagonebag:SetChecked(BK_Setting.BagBarOneBag)
		bagonebag:SetScript("OnClick", function()
			if BK_Setting.BagBarOneBag then BarKeepOptions_BagBarOneBag(false) else BarKeepOptions_BagBarOneBag(true) end
		end)
		bagonebag:SetPoint("LEFT", bagtoggle, "RIGHT",90,0)
		
		local bagvertical = CreateFrame("CheckButton", ("BarKeep_BagBarVertical"), Options,"OptionsCheckButtonTemplate")
		getglobal(bagvertical:GetName() .. "Text"):SetText(L["BagBar Vertical"])
		getglobal(bagvertical:GetName() .. "Text"):SetFontObject(GameFontNormalSmall)
		bagvertical:SetChecked(BK_Setting.BagBarVertical)
		bagvertical:SetScript("OnClick", function()
			-- Check whether hidden or not
			if BK_Setting.BagBarVertical then BarKeepOptions_BagBarVertical(false) else BarKeepOptions_BagBarVertical(true) end
		end)
		bagvertical:SetPoint("TOPLEFT", bagtoggle, "BOTTOMLEFT",0,10)
		
		local bagkeyring = CreateFrame("CheckButton", ("BarKeep_BagBarKeyRing"), Options,"OptionsCheckButtonTemplate")
		getglobal(bagkeyring:GetName() .. "Text"):SetText(L["BagBar KeyRing"])
		getglobal(bagkeyring:GetName() .. "Text"):SetFontObject(GameFontNormalSmall)
		bagkeyring:SetChecked(BK_Setting.BagBarKeyRing)
		bagkeyring:SetScript("OnClick", function()
			if BK_Setting.BagBarKeyRing then BarKeepOptions_BagBarKeyRing(false) else BarKeepOptions_BagBarKeyRing(true) end
		end)
		bagkeyring:SetPoint("TOPLEFT", bagvertical, "BOTTOMLEFT",0,10)

		local bbsc = CreateFrame("Slider", ("BarKeep_BagBarScale"), Options,"OptionsSliderTemplate")
		bbsc:SetWidth(100)
		bbsc:SetMinMaxValues(0.4,1.0)
		bbsc:SetValueStep(0.01)
		bbsc:SetValue(BK_Setting.BagBarScale)
		local name = bbsc:GetName()
		getglobal(name .. "Text"):SetText(L["BagBar Scale"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("0.4")
		getglobal(name .. "High"):SetText("1.0")
		local bbsctext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		bbsctext:SetPoint("LEFT", bbsc, "RIGHT")
		bbsc.valText = bbsctext
		bbsc.valText:SetText(format("%.2f", BK_Setting.BagBarScale))
		bbsc:SetScript("OnValueChanged", function(self, value)
			bbsc.valText:SetText(format("%.2f", value))
			BK_Setting.BagBarScale = value
			BarKeepOptions_ScaleBagBar(BK_Setting.BagBarScale)
			BarKeep_MainBarUpdate()
		end)
		bbsc:SetPoint("LEFT", bagkeyring, "RIGHT",98,4) -- May need to adjust this to line up the scale bars
		
		-- MainBar  & VehicleBar Options
		local mbbs = CreateFrame("Slider", ("BarKeep_MainBarButtons"), Options,"OptionsSliderTemplate")
		mbbs:SetWidth(100)
		mbbs:SetMinMaxValues(1,12)
		mbbs:SetValueStep(1)
		mbbs:SetValue(BK_Setting.MainBarButtons)
		local name = mbbs:GetName()
		getglobal(name .. "Text"):SetText(L["MainBar Buttons"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("1")
		getglobal(name .. "High"):SetText("12")
		local mbbstext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		mbbstext:SetPoint("LEFT", mbbs, "RIGHT")
		mbbs.valText = mbbstext
		mbbs.valText:SetText(format("%.0f", BK_Setting.MainBarButtons))
		mbbs:SetScript("OnValueChanged", function(self, value)
			mbbs.valText:SetText(format("%.0f", value))
			BK_Setting.MainBarButtons = value
			BarKeepOptions_ShowButtons("ActionButton")
			BarKeepOptions_ShowButtons("BonusActionButton")
			BarKeep_MainBarUpdate()
		end)
		mbbs:SetPoint("TOPLEFT", bagkeyring, "BOTTOMLEFT",0,-20)
		
		local mbrs = CreateFrame("Slider", ("BarKeep_MainBarRows"), Options,"OptionsSliderTemplate")
		mbrs:SetWidth(100)
		mbrs:SetMinMaxValues(1,12)
		mbrs:SetValueStep(1)
		mbrs:SetValue(BK_Setting.MainBarRows)
		local name = mbrs:GetName()
		getglobal(name .. "Text"):SetText(L["MainBar Rows"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("1")
		getglobal(name .. "High"):SetText("12")
		local mbrstext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		mbrstext:SetPoint("LEFT", mbrs, "RIGHT")
		mbrs.valText = mbrstext
		mbrs.valText:SetText(format("%.0f", BK_Setting.MainBarRows))
		mbrs:SetScript("OnValueChanged", function(self, value)
			mbrs.valText:SetText(format("%.0f", value))
			BK_Setting.MainBarRows = value
			BarKeep_MainBarUpdate()
		end)
		mbrs:SetPoint("LEFT", mbbs, "RIGHT",20,0)

		local mbsc = CreateFrame("Slider", ("BarKeep_MainBarScale"), Options,"OptionsSliderTemplate")
		mbsc:SetWidth(100)
		mbsc:SetMinMaxValues(0.4,1.0)
		mbsc:SetValueStep(0.01)
		mbsc:SetValue(BK_Setting.MainBarScale)
		local name = mbsc:GetName()
		getglobal(name .. "Text"):SetText(L["MainBar Scale"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("0.4")
		getglobal(name .. "High"):SetText("1.0")
		local mbsctext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		mbsctext:SetPoint("LEFT", mbsc, "RIGHT")
		mbsc.valText = mbsctext
		mbsc.valText:SetText(format("%.2f", BK_Setting.MainBarScale))
		mbsc:SetScript("OnValueChanged", function(self, value)
			mbsc.valText:SetText(format("%.2f", value))
			BK_Setting.MainBarScale = value
			BarKeepOptions_ScaleBars()
			BarKeep_MainBarUpdate()
			BarKeep_VehicleBarUpdate()
		end)
		mbsc:SetPoint("TOPLEFT", mbbs, "BOTTOMLEFT",0,-20)

		local vbsc = CreateFrame("Slider", ("BarKeep_VehicleBarScale"), Options,"OptionsSliderTemplate")
		vbsc:SetWidth(100)
		vbsc:SetMinMaxValues(0.4,1.0)
		vbsc:SetValueStep(0.01)
		vbsc:SetValue(BK_Setting.VehicleBarScale)
		local name = vbsc:GetName()
		getglobal(name .. "Text"):SetText(L["VehicleBar Scale"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("0.4")
		getglobal(name .. "High"):SetText("1.0")
		local vbsctext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		vbsctext:SetPoint("LEFT", mbsc, "RIGHT")
		vbsc.valText = vbsctext
		vbsc.valText:SetText(format("%.2f", BK_Setting.VehicleBarScale))
		vbsc:SetScript("OnValueChanged", function(self, value)
			vbsc.valText:SetText(format("%.2f", value))
			BK_Setting.VehicleBarScale = value
			BarKeepOptions_ScaleBars()
			BarKeep_MainBarUpdate()
			BarKeep_VehicleBarUpdate()
		end)
		vbsc:SetPoint("LEFT", mbsc, "RIGHT",20,0)
		
		-- BottomLeftBar Options
		local lbbs = CreateFrame("Slider", ("BarKeep_LeftBarButtons"), Options,"OptionsSliderTemplate")
		lbbs:SetWidth(100)
		lbbs:SetMinMaxValues(1,12)
		lbbs:SetValueStep(1)
		lbbs:SetValue(BK_Setting.LeftBarButtons)
		local name = lbbs:GetName()
		getglobal(name .. "Text"):SetText(L["LeftBar Buttons"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("1")
		getglobal(name .. "High"):SetText("12")
		local lbbstext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		lbbstext:SetPoint("LEFT", lbbs, "RIGHT")
		lbbs.valText = lbbstext
		lbbs.valText:SetText(format("%.0f", BK_Setting.LeftBarButtons))
		lbbs:SetScript("OnValueChanged", function(self, value)
			lbbs.valText:SetText(format("%.0f", value))
			BK_Setting.LeftBarButtons = value
			BarKeepOptions_ShowButtons("MultiBarBottomLeftButton")
			BarKeep_MainBarUpdate()
		end)
		lbbs:SetPoint("TOPLEFT", mbsc, "BOTTOMLEFT",0,-20)
		
		local lbrs = CreateFrame("Slider", ("BarKeep_LeftBarRows"), Options,"OptionsSliderTemplate")
		lbrs:SetWidth(100)
		lbrs:SetMinMaxValues(1,12)
		lbrs:SetValueStep(1)
		lbrs:SetValue(BK_Setting.LeftBarRows)
		local name = lbrs:GetName()
		getglobal(name .. "Text"):SetText(L["LeftBar Rows"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("1")
		getglobal(name .. "High"):SetText("12")
		local lbrstext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		lbrstext:SetPoint("LEFT", lbrs, "RIGHT")
		lbrs.valText = lbrstext
		lbrs.valText:SetText(format("%.0f", BK_Setting.LeftBarRows))
		lbrs:SetScript("OnValueChanged", function(self, value)
			lbrs.valText:SetText(format("%.0f", value))
			BK_Setting.LeftBarRows = value
			BarKeep_MainBarUpdate()
		end)
		lbrs:SetPoint("LEFT", lbbs, "RIGHT",20,0)

		local lbsc = CreateFrame("Slider", ("BarKeep_LeftBarScale"), Options,"OptionsSliderTemplate")
		lbsc:SetWidth(100)
		lbsc:SetMinMaxValues(0.4,1.0)
		lbsc:SetValueStep(0.01)
		lbsc:SetValue(BK_Setting.LeftBarScale)
		local name = lbsc:GetName()
		getglobal(name .. "Text"):SetText(L["LeftBar Scale"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("0.4")
		getglobal(name .. "High"):SetText("1.0")
		local lbsctext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		lbsctext:SetPoint("LEFT", lbsc, "RIGHT")
		lbsc.valText = lbsctext
		lbsc.valText:SetText(format("%.2f", BK_Setting.LeftBarScale))
		lbsc:SetScript("OnValueChanged", function(self, value)
			lbsc.valText:SetText(format("%.2f", value))
			BK_Setting.LeftBarScale = value
			BarKeepOptions_ScaleBars()
			BarKeep_MainBarUpdate()
		end)
		lbsc:SetPoint("LEFT", lbrs, "RIGHT",20,0)

		-- BottomRightBar Options
		local rbbs = CreateFrame("Slider", ("BarKeep_RightBarButtons"), Options,"OptionsSliderTemplate")
		rbbs:SetWidth(100)
		rbbs:SetMinMaxValues(1,12)
		rbbs:SetValueStep(1)
		rbbs:SetValue(BK_Setting.RightBarButtons)
		local name = rbbs:GetName()
		getglobal(name .. "Text"):SetText(L["RightBar Buttons"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("1")
		getglobal(name .. "High"):SetText("12")
		local rbbstext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		rbbstext:SetPoint("LEFT", rbbs, "RIGHT")
		rbbs.valText = rbbstext
		rbbs.valText:SetText(format("%.0f", BK_Setting.RightBarButtons))
		rbbs:SetScript("OnValueChanged", function(self, value)
			rbbs.valText:SetText(format("%.0f", value))
			BK_Setting.RightBarButtons = value
			BarKeepOptions_ShowButtons("MultiBarBottomRightButton")
			BarKeep_MainBarUpdate()
		end)
		rbbs:SetPoint("TOPLEFT", lbbs, "BOTTOMLEFT",0,-20)
		
		local rbrs = CreateFrame("Slider", ("BarKeep_RightBarRows"), Options,"OptionsSliderTemplate")
		rbrs:SetWidth(100)
		rbrs:SetMinMaxValues(1,12)
		rbrs:SetValueStep(1)
		rbrs:SetValue(BK_Setting.RightBarRows)
		local name = rbrs:GetName()
		getglobal(name .. "Text"):SetText(L["RightBar Rows"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("1")
		getglobal(name .. "High"):SetText("12")
		local rbrstext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		rbrstext:SetPoint("LEFT", rbrs, "RIGHT")
		rbrs.valText = rbrstext
		rbrs.valText:SetText(format("%.0f", BK_Setting.RightBarRows))
		rbrs:SetScript("OnValueChanged", function(self, value)
			rbrs.valText:SetText(format("%.0f", value))
			BK_Setting.RightBarRows = value
			BarKeep_MainBarUpdate()
		end)
		rbrs:SetPoint("LEFT", rbbs, "RIGHT",20,0)

		local rbsc = CreateFrame("Slider", ("BarKeep_RightBarScale"), Options,"OptionsSliderTemplate")
		rbsc:SetWidth(100)
		rbsc:SetMinMaxValues(0.4,1.0)
		rbsc:SetValueStep(0.01)
		rbsc:SetValue(BK_Setting.RightBarScale)
		local name = rbsc:GetName()
		getglobal(name .. "Text"):SetText(L["RightBar Scale"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("0.4")
		getglobal(name .. "High"):SetText("1.0")
		local rbsctext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		rbsctext:SetPoint("LEFT", rbsc, "RIGHT")
		rbsc.valText = rbsctext
		rbsc.valText:SetText(format("%.2f", BK_Setting.RightBarScale))
		rbsc:SetScript("OnValueChanged", function(self, value)
			rbsc.valText:SetText(format("%.2f", value))
			BK_Setting.RightBarScale = value
			BarKeepOptions_ScaleBars()
			BarKeep_MainBarUpdate()
		end)
		rbsc:SetPoint("LEFT", rbrs, "RIGHT",20,0)

		-- MultiBarLeft Options
		local mblbs = CreateFrame("Slider", ("BarKeep_MultiBarLeftButtons"), Options,"OptionsSliderTemplate")
		mblbs:SetWidth(100)
		mblbs:SetMinMaxValues(1,12)
		mblbs:SetValueStep(1)
		mblbs:SetValue(BK_Setting.MultiBarLeftButtons)
		local name = mblbs:GetName()
		getglobal(name .. "Text"):SetText(L["MultiBarLeft Buttons"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("1")
		getglobal(name .. "High"):SetText("12")
		local mblbstext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		mblbstext:SetPoint("LEFT", mblbs, "RIGHT")
		mblbs.valText = mblbstext
		mblbs.valText:SetText(format("%.0f", BK_Setting.MultiBarLeftButtons))
		mblbs:SetScript("OnValueChanged", function(self, value)
			mblbs.valText:SetText(format("%.0f", value))
			BK_Setting.MultiBarLeftButtons = value
			BarKeepOptions_ShowButtons("MultiBarLeftButton")
			BarKeep_MainBarUpdate()
		end)
		mblbs:SetPoint("TOPLEFT", rbbs, "BOTTOMLEFT",0,-20)
		
		local mblrs = CreateFrame("Slider", ("BarKeep_MultiBarLeftRows"), Options,"OptionsSliderTemplate")
		mblrs:SetWidth(100)
		mblrs:SetMinMaxValues(1,12)
		mblrs:SetValueStep(1)
		mblrs:SetValue(BK_Setting.MultiBarLeftRows)
		local name = mblrs:GetName()
		getglobal(name .. "Text"):SetText(L["MultiBarLeft Rows"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("1")
		getglobal(name .. "High"):SetText("12")
		local mblrstext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		mblrstext:SetPoint("LEFT", mblrs, "RIGHT")
		mblrs.valText = mblrstext
		mblrs.valText:SetText(format("%.0f", BK_Setting.MultiBarLeftRows))
		mblrs:SetScript("OnValueChanged", function(self, value)
			mblrs.valText:SetText(format("%.0f", value))
			BK_Setting.MultiBarLeftRows = value
			BarKeep_MainBarUpdate()
		end)
		mblrs:SetPoint("LEFT", mblbs, "RIGHT",20,0)

		local mblsc = CreateFrame("Slider", ("BarKeep_MultiBarLeftScale"), Options,"OptionsSliderTemplate")
		mblsc:SetWidth(100)
		mblsc:SetMinMaxValues(0.4,1.0)
		mblsc:SetValueStep(0.01)
		mblsc:SetValue(BK_Setting.MultiBarLeftScale)
		local name = mblsc:GetName()
		getglobal(name .. "Text"):SetText(L["MultiBarLeft Scale"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("0.4")
		getglobal(name .. "High"):SetText("1.0")
		local mblsctext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		mblsctext:SetPoint("LEFT", mblsc, "RIGHT")
		mblsc.valText = mblsctext
		mblsc.valText:SetText(format("%.2f", BK_Setting.MultiBarLeftScale))
		mblsc:SetScript("OnValueChanged", function(self, value)
			mblsc.valText:SetText(format("%.2f", value))
			BK_Setting.MultiBarLeftScale = value
			BarKeepOptions_ScaleBars()
			BarKeep_MainBarUpdate()
		end)
		mblsc:SetPoint("LEFT", mblrs, "RIGHT",20,0)

		-- MultiBarRight Options
		local mbrbs = CreateFrame("Slider", ("BarKeep_MultiBarRightButtons"), Options,"OptionsSliderTemplate")
		mbrbs:SetWidth(100)
		mbrbs:SetMinMaxValues(1,12)
		mbrbs:SetValueStep(1)
		mbrbs:SetValue(BK_Setting.MultiBarRightButtons)
		local name = mbrbs:GetName()
		getglobal(name .. "Text"):SetText(L["MultiBarRight Buttons"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("1")
		getglobal(name .. "High"):SetText("12")
		local mbrbstext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		mbrbstext:SetPoint("LEFT", mbrbs, "RIGHT")
		mbrbs.valText = mbrbstext
		mbrbs.valText:SetText(format("%.0f", BK_Setting.MultiBarRightButtons))
		mbrbs:SetScript("OnValueChanged", function(self, value)
			mbrbs.valText:SetText(format("%.0f", value))
			BK_Setting.MultiBarRightButtons = value
			BarKeepOptions_ShowButtons("MultiBarRightButton")
			BarKeep_MainBarUpdate()
		end)
		mbrbs:SetPoint("TOPLEFT", mblbs, "BOTTOMLEFT",0,-20)
		
		local mbrrs = CreateFrame("Slider", ("BarKeep_MultiBarRightRows"), Options,"OptionsSliderTemplate")
		mbrrs:SetWidth(100)
		mbrrs:SetMinMaxValues(1,12)
		mbrrs:SetValueStep(1)
		mbrrs:SetValue(BK_Setting.MultiBarRightRows)
		local name = mbrrs:GetName()
		getglobal(name .. "Text"):SetText(L["MultiBarRight Rows"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("1")
		getglobal(name .. "High"):SetText("12")
		local mbrrstext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		mbrrstext:SetPoint("LEFT", mbrrs, "RIGHT")
		mbrrs.valText = mbrrstext
		mbrrs.valText:SetText(format("%.0f", BK_Setting.MultiBarRightRows))
		mbrrs:SetScript("OnValueChanged", function(self, value)
			mbrrs.valText:SetText(format("%.0f", value))
			BK_Setting.MultiBarRightRows = value
			BarKeep_MainBarUpdate()
		end)
		mbrrs:SetPoint("LEFT", mbrbs, "RIGHT",20,0)

		local mbrsc = CreateFrame("Slider", ("BarKeep_MultiBarRightScale"), Options,"OptionsSliderTemplate")
		mbrsc:SetWidth(100)
		mbrsc:SetMinMaxValues(0.4,1.0)
		mbrsc:SetValueStep(0.01)
		mbrsc:SetValue(BK_Setting.MultiBarRightScale)
		local name = mbrsc:GetName()
		getglobal(name .. "Text"):SetText(L["MultiBarRight Scale"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("0.4")
		getglobal(name .. "High"):SetText("1.0")
		local mbrsctext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		mbrsctext:SetPoint("LEFT", mbrsc, "RIGHT")
		mbrsc.valText = mbrsctext
		mbrsc.valText:SetText(format("%.2f", BK_Setting.MultiBarRightScale))
		mbrsc:SetScript("OnValueChanged", function(self, value)
			mbrsc.valText:SetText(format("%.2f", value))
			BK_Setting.MultiBarRightScale = value
			BarKeepOptions_ScaleBars()
			BarKeep_MainBarUpdate()
		end)
		mbrsc:SetPoint("LEFT", mbrrs, "RIGHT",20,0)

		-- Pet Bar and Possess Bar Scaling Options
		local petbrs = CreateFrame("Slider", ("BarKeep_PetBarRows"), Options,"OptionsSliderTemplate")
		petbrs:SetWidth(100)
		petbrs:SetMinMaxValues(1,10)
		petbrs:SetValueStep(1)
		petbrs:SetValue(BK_Setting.PetBarRows)
		local name = petbrs:GetName()
		getglobal(name .. "Text"):SetText(L["PetBar Rows"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("1")
		getglobal(name .. "High"):SetText("10")
		local petbrstext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		petbrstext:SetPoint("LEFT", petbrs, "RIGHT")
		petbrs.valText = petbrstext
		petbrs.valText:SetText(format("%.0f", BK_Setting.PetBarRows))
		petbrs:SetScript("OnValueChanged", function(self, value)
			petbrs.valText:SetText(format("%.0f", value))
			BK_Setting.PetBarRows = value
			BarKeep_MainBarUpdate()
		end)
		petbrs:SetPoint("TOPLEFT", mbrbs, "BOTTOMLEFT",0,-20)

		local petbsc = CreateFrame("Slider", ("BarKeep_PetBarScale"), Options,"OptionsSliderTemplate")
		petbsc:SetWidth(100)
		petbsc:SetMinMaxValues(0.4,1.0)
		petbsc:SetValueStep(0.01)
		petbsc:SetValue(BK_Setting.PetBarScale)
		local name = petbsc:GetName()
		getglobal(name .. "Text"):SetText(L["PetBar Scale"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("0.4")
		getglobal(name .. "High"):SetText("1.0")
		local petbsctext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		petbsctext:SetPoint("LEFT", petbsc, "RIGHT")
		petbsc.valText = petbsctext
		petbsc.valText:SetText(format("%.2f", BK_Setting.PetBarScale))
		petbsc:SetScript("OnValueChanged", function(self, value)
			petbsc.valText:SetText(format("%.2f", value))
			BK_Setting.PetBarScale = value
			BarKeepOptions_ScalePetBar(BK_Setting.PetBarScale)
			BarKeep_MainBarUpdate()
		end)
		petbsc:SetPoint("LEFT", petbrs, "RIGHT",20,0)

		
		local pssbsc = CreateFrame("Slider", ("BarKeep_PossessBarScale"), Options,"OptionsSliderTemplate")
		pssbsc:SetWidth(100)
		pssbsc:SetMinMaxValues(0.4,1.0)
		pssbsc:SetValueStep(0.01)
		pssbsc:SetValue(BK_Setting.PossessBarScale)
		local name = pssbsc:GetName()
		getglobal(name .. "Text"):SetText(L["PossessBar Scale"])
		getglobal(name .. "Text"):SetFontObject(GameFontNormalSmall)
		getglobal(name .. "Low"):SetText("0.4")
		getglobal(name .. "High"):SetText("1.0")
		local pssbsctext = Options:CreateFontString(nil, "BACKGROUND","GameFontHighlightSmall")
		pssbsctext:SetPoint("LEFT", pssbsc, "RIGHT")
		pssbsc.valText = pssbsctext
		pssbsc.valText:SetText(format("%.2f", BK_Setting.PossessBarScale))
		pssbsc:SetScript("OnValueChanged", function(self, value)
			pssbsc.valText:SetText(format("%.2f", value))
			BK_Setting.PossessBarScale = value
			BarKeepOptions_ScalePossessBar(BK_Setting.PossessBarScale)
			BarKeep_MainBarUpdate()
		end)
		pssbsc:SetPoint("LEFT", petbsc, "RIGHT",20,0)

		-- Only run the frame creation once so disable once frame creation has occured
		self:SetScript("OnShow", nil)
	end)

	InterfaceOptions_AddCategory(Options)

	-- Establish the slash command and send to the  configuration screen
	SlashCmdList["BarKeepOptions"] = function()
		InterfaceOptionsFrame_OpenToCategory("BarKeep")
	end	
	SLASH_BarKeepOptions1 = "/barkeep"
	SLASH_BarKeepOptions2 = "/bk"
end

function BarKeepOptions_OnEvent(event)
	if event == "VARIABLES_LOADED" then
		if BK_Setting == nil  then BarKeepOptions_LoadDefault() end
		-- temporary code for adding new settings elegantly
		
	elseif event == "PLAYER_ENTERING_WORLD" then
		BarKeepOptions_Init()
		BarKeepOptions_UpdateState()
	end
end

function BarKeepOptions_LoadDefault()
	BK_Setting = {}
	BK_Setting.Locked = false

	-- Bag Bar Settings
	BK_Setting.BagBarHide = false
	BK_Setting.BagBarScale = 0.8
	BK_Setting.BagBarVertical = false
	BK_Setting.BagBarOneBag = false
	BK_Setting.BagBarKeyRing = true

	-- Menu Bar Settings
	BK_Setting.MenuBarHide = false

	-- Action Bar Settings
	BK_Setting.MainBarScale = 1.0
	BK_Setting.MainBarRows = 1
	BK_Setting.MainBarButtons = 12
	BK_Setting.VehicleBarScale = 1.0

	BK_Setting.LeftBarScale = 1.0
	BK_Setting.LeftBarRows = 1
	BK_Setting.LeftBarButtons = 12

	BK_Setting.RightBarScale = 1.0
	BK_Setting.RightBarRows = 1
	BK_Setting.RightBarButtons = 12
	
	BK_Setting.MultiBarLeftScale = 1.0
	BK_Setting.MultiBarLeftRows = 12
	BK_Setting.MultiBarLeftButtons = 12
	
	BK_Setting.MultiBarRightScale = 1.0
	BK_Setting.MultiBarRightRows = 12
	BK_Setting.MultiBarRightButtons = 12

	-- Pet / Possess /Shape / Totem Bar Settings
	BK_Setting.PetBarScale = 0.8
	BK_Setting.PetBarRows = 1
	BK_Setting.PossessBarScale = 0.8
	BK_Setting.ShapeBarHide = false
end

function BarKeepOptions_Init()

	local BagStuff = {
		"MainMenuBarBackpackButton", "CharacterBag0Slot", "CharacterBag1Slot", "CharacterBag2Slot",	"CharacterBag3Slot", "KeyRingButton",
	}
	for index,value in pairs(BagStuff) do
		_G[value]:ClearAllPoints()
		_G[value]:SetParent("BarKeepBagFrame")
		_G[value]:SetFrameStrata("MEDIUM")
	end
	MainMenuBarBackpackButton:SetScale(0.8)
	MainMenuBarBackpackButton:SetPoint("TOPRIGHT","BarKeepBagFrame","TOPRIGHT",0,0)

	local MainMenuStuff = {
		"CharacterMicroButton", "SpellbookMicroButton", "TalentMicroButton", "AchievementMicroButton", "QuestLogMicroButton",
		"SocialsMicroButton", "PVPMicroButton", "LFGMicroButton", "MainMenuMicroButton", "HelpMicroButton"}
	for index,value in pairs(MainMenuStuff) do
		_G[value]:ClearAllPoints()
		_G[value]:SetParent("BarKeepMainMenuFrame")
		_G[value]:SetFrameStrata("MEDIUM")
		_G[value]:SetScale(0.8)
	end
	
	CharacterMicroButton:SetPoint("TOPLEFT","BarKeepMainMenuFrame","TOPLEFT",0,0)
	SpellbookMicroButton:SetPoint("BOTTOMLEFT","CharacterMicroButton","BOTTOMRIGHT",-3,0)
	TalentMicroButton:SetPoint("BOTTOMLEFT","SpellbookMicroButton","BOTTOMRIGHT",-3,0)
	UpdateTalentButton()				-- Use the Blizzard code to place the Achievement button to avoid a potential LUA error
	AchievementMicroButton_Update()		-- Use the Blizzard code to place the QuestLog button avoid a potential LUA error
	SocialsMicroButton:SetPoint("BOTTOMLEFT","QuestLogMicroButton","BOTTOMRIGHT",-3,0)
	PVPMicroButton:SetPoint("BOTTOMLEFT","SocialsMicroButton","BOTTOMRIGHT",-3,0)
	LFGMicroButton:SetPoint("BOTTOMLEFT","PVPMicroButton","BOTTOMRIGHT",-3,0)
	MainMenuMicroButton:SetPoint("BOTTOMLEFT","LFGMicroButton","BOTTOMRIGHT",-3,0)	
	HelpMicroButton:SetPoint("BOTTOMLEFT","MainMenuMicroButton","BOTTOMRIGHT",-3,0)
end

function BarKeepOptions_UpdateState()

	if BK_Setting.Locked then
		BarKeepBagDragButton:Hide()
		BarKeepMainMenuBarDragButton:Hide()
		BarKeepMultiBarBottomRightDragButton:Hide()
		BarKeepMultiBarBottomLeftDragButton:Hide()
		BarKeepMultiBarRightDragButton:Hide()
		BarKeepMultiBarLeftDragButton:Hide()

		BarKeepPetDragButton:Hide()
		BarKeepPetFrameVisible:Hide()

		BarKeepPossessDragButton:Hide()
		BarKeepPossessFrameVisible:Hide()

		BarKeepVehicleBarDragButton:Hide()
		BarKeepVehicleBarFrameVisible:Hide()

	else

		BarKeepBagDragButton:Show()
		BarKeepMainMenuBarDragButton:Show()
		BarKeepMultiBarBottomRightDragButton:Show()
		BarKeepMultiBarBottomLeftDragButton:Show()
		BarKeepMultiBarRightDragButton:Show()
		BarKeepMultiBarLeftDragButton:Show()

		BarKeepPetDragButton:Show()
		BarKeepPetFrameVisible:SetPoint("BOTTOMRIGHT","PetActionButton10","BOTTOMRIGHT")
		local bg = BarKeepPetFrameVisible:CreateTexture(nil, "BACKGROUND")
		bg:SetTexture(0, 0, 0, 0.5)
		bg:SetAllPoints(BarKeepPetFrameVisible)
		BarKeepPetFrameVisible:SetNormalTexture(bg)
		BarKeepPetFrameVisible:Show()

		BarKeepPetFrameVisible:SetNormalFontObject("GameFontNormalLarge")
		BarKeepPetFrameVisible:SetText(L["pet"])

		BarKeepPossessDragButton:Show()
		BarKeepPossessFrameVisible:SetPoint("BOTTOMRIGHT","PossessButton2","BOTTOMRIGHT")
		local bg = BarKeepPossessFrameVisible:CreateTexture(nil, "BACKGROUND")
		bg:SetTexture(0, 0, 0, 0.5)
		bg:SetAllPoints(BarKeepPossessFrameVisible)
		BarKeepPossessFrameVisible:SetNormalTexture(bg)
		BarKeepPossessFrameVisible:Show()

		BarKeepPossessFrameVisible:SetNormalFontObject("GameFontNormalLarge")
		BarKeepPossessFrameVisible:SetText(L["possess"])

		BarKeepVehicleBarDragButton:Show()
		BarKeepVehicleBarFrameVisible:SetPoint("BOTTOM","VehicleMenuBarActionButton1","BOTTOM")
		BarKeepVehicleBarFrameVisible:SetPoint("RIGHT","VehicleMenuBarLeaveButton","RIGHT")
		local bg = BarKeepVehicleBarFrameVisible:CreateTexture(nil, "BACKGROUND")
		bg:SetTexture(0, 0, 0, 0.5)
		bg:SetAllPoints(BarKeepVehicleBarFrameVisible)
		BarKeepVehicleBarFrameVisible:SetNormalTexture(bg)
		BarKeepVehicleBarFrameVisible:Show()

		BarKeepVehicleBarFrameVisible:SetNormalFontObject("GameFontNormalLarge")
		BarKeepVehicleBarFrameVisible:SetText(L["vehicle"])
		
	end
	
	if ShapeshiftBarFrame:IsShown() then
		if BK_Setting.Locked then
			BarKeepShapeDragButton:Hide()
		else
			BarKeepShapeDragButton:Show()
		end
	else
		BarKeepShapeDragButton:Hide()
	end

	if TotemFrame:IsShown() then 
		if BK_Setting.Locked then
			BarKeepTotemDragButton:Hide()
		else
			BarKeepTotemDragButton:Show()
		end
	else
		BarKeepTotemDragButton:Hide()
	end
	
	if BK_Setting.ShapeBarHide then
		BarKeepOptions_HideShapeBar()
	else
		BarKeepOptions_ShowShapeBar()
	end

	BarKeepOptions_BagBarShowHide(BK_Setting.BagBarHide)
	BarKeepOptions_BagBarVertical(BK_Setting.BagBarVertical)

	if not BK_Setting.MainBarScale then	BK_Setting.MainBarScale = 1.0 end
	if not BK_Setting.VehicleBarScale then BK_Setting.VehicleBarScale = BK_Setting.MainBarScale end
	if not BK_Setting.LeftBarScale then BK_Setting.LeftBarScale = 1.0 end
	if not BK_Setting.RightBarScale then BK_Setting.RightBarScale = 1.0 end
	if not BK_Setting.MultiBarLeftScale then BK_Setting.MultiBarLeftScale = 1.0 end
	if not BK_Setting.MultiBarRightScale then BK_Setting.MultiBarRightScale = 1.0 end
	BarKeepOptions_ScaleBars()
	
	if not BK_Setting.BagBarScale then BK_Setting.BagBarScale = 0.8 end
	BarKeepOptions_ScaleBagBar(BK_Setting.BagBarScale)
	
	if not BK_Setting.PetBarScale then BK_Setting.PetBarScale = 0.8 end
	BarKeepOptions_ScalePetBar(BK_Setting.PetBarScale)

	if not BK_Setting.PossessBarScale then BK_Setting.PossessBarScale = 0.8 end
	BarKeepOptions_ScalePossessBar(BK_Setting.PossessBarScale)
	
	if BK_Setting.MenuBarHide then
		BarKeepMainMenuDragButton:Hide()
		BarKeepMainMenuFrame:Hide()
	else 
		if BK_Setting.Locked then
			BarKeepMainMenuDragButton:Hide()
		else
			BarKeepMainMenuDragButton:Show()
		end
		BarKeepMainMenuFrame:Show()
	end
end

function BarKeepOptions_ScaleBars()
	BarKeepMainMenuBarFrame:SetScale(BK_Setting.MainBarScale)
	MainMenuBar:SetScale(BK_Setting.MainBarScale)
	
	BarKeepShapeFrame:SetScale(BK_Setting.MainBarScale)
	BarKeepTotemFrame:SetScale(BK_Setting.MainBarScale)

	BarKeepVehicleBarFrame:SetScale(BK_Setting.VehicleBarScale)
	VehicleMenuBar:SetScale(BK_Setting.VehicleBarScale)
	BarKeepVehicleBarFrameVisible:SetScale(BK_Setting.VehicleBarScale)
	
	BarKeepMultiBarBottomLeftFrame:SetScale(BK_Setting.LeftBarScale)
	MultiBarBottomLeft:SetScale(BK_Setting.LeftBarScale)

	BarKeepMultiBarBottomRightFrame:SetScale(BK_Setting.RightBarScale)
	MultiBarBottomRight:SetScale(BK_Setting.RightBarScale)

	BarKeepMultiBarRightFrame:SetScale(BK_Setting.MultiBarRightScale)
	MultiBarRight:SetScale(BK_Setting.MultiBarRightScale)

	BarKeepMultiBarLeftFrame:SetScale(BK_Setting.MultiBarLeftScale)
	MultiBarLeft:SetScale(BK_Setting.MultiBarLeftScale)
end
	
function BarKeepOptions_ScalePetBar(scale)
	PetActionBarFrame:SetScale(scale)
	BarKeepPetFrame:SetScale(scale)
	BarKeepPetFrameVisible:SetScale(scale)
end

function BarKeepOptions_ScalePossessBar(scale)
	PossessBarFrame:SetScale(scale)
	BarKeepPossessFrameVisible:SetScale(scale)
end

function BarKeepOptions_BagBarOneBag(value)
	BK_Setting.BagBarOneBag = value
	BarKeepOptions_BagBarShowHide(BK_Setting.BagBarHide)
end

function BarKeepOptions_BagBarKeyRing(value)
	BK_Setting.BagBarKeyRing = value
	BarKeepOptions_BagBarShowHide(BK_Setting.BagBarHide)
end

function BarKeepOptions_BagBarShowHide(value)
	BK_Setting.BagBarHide = value
	if BK_Setting.BagBarHide then
		BarKeepBagDragButton:Hide()
		MainMenuBarBackpackButton:Hide()
		CharacterBag0Slot:Hide()
		CharacterBag1Slot:Hide()
		CharacterBag2Slot:Hide()
		CharacterBag3Slot:Hide()
		KeyRingButton:Hide()
	else
		if BK_Setting.Locked then
			BarKeepBagDragButton:Hide()
		else
			BarKeepBagDragButton:Show()
		end
		MainMenuBarBackpackButton:Show()
		if BK_Setting.BagBarOneBag then
			CharacterBag0Slot:Hide()
			CharacterBag1Slot:Hide()
			CharacterBag2Slot:Hide()
			CharacterBag3Slot:Hide()
		else
			CharacterBag0Slot:Show()
			CharacterBag1Slot:Show()
			CharacterBag2Slot:Show()
			CharacterBag3Slot:Show()
		end
		if BK_Setting.BagBarKeyRing then
			BarKeepOptions_BagBarVertical(BK_Setting.BagBarVertical)
			KeyRingButton:Show()
		else
			KeyRingButton:Hide()
		end
	end
end

function BarKeepOptions_BagBarVertical(value)
	BK_Setting.BagBarVertical = value
	CharacterBag0Slot:ClearAllPoints()
	CharacterBag1Slot:ClearAllPoints()
	CharacterBag2Slot:ClearAllPoints()
	CharacterBag3Slot:ClearAllPoints()
	KeyRingButton:ClearAllPoints()
	if BK_Setting.BagBarVertical then
		CharacterBag0Slot:SetPoint("TOPLEFT","MainMenuBarBackpackButton","BOTTOMLEFT",0,-3)
		CharacterBag1Slot:SetPoint("TOPLEFT","CharacterBag0Slot","BOTTOMLEFT",0,-3)
		CharacterBag2Slot:SetPoint("TOPLEFT","CharacterBag1Slot","BOTTOMLEFT",0,-3)
		CharacterBag3Slot:SetPoint("TOPLEFT","CharacterBag2Slot","BOTTOMLEFT",0,-3)
	else
		CharacterBag0Slot:SetPoint("RIGHT","MainMenuBarBackpackButton","LEFT",-3,0)
		CharacterBag1Slot:SetPoint("RIGHT","CharacterBag0Slot","LEFT",-3,0)
		CharacterBag2Slot:SetPoint("RIGHT","CharacterBag1Slot","LEFT",-3,0)
		CharacterBag3Slot:SetPoint("RIGHT","CharacterBag2Slot","LEFT",-3,0)
	end
	if BK_Setting.BagBarOneBag then
		KeyRingButton:SetPoint("RIGHT","MainMenuBarBackpackButton","LEFT",-3,0)
	else
		KeyRingButton:SetPoint("RIGHT","CharacterBag3Slot","LEFT",-3,0)
	end
end

function BarKeepOptions_ScaleBagBar(scale)
	BarKeepBagFrame:SetScale(scale)
end

function BarKeepOptions_HideShapeBar()
	BK_Setting.ShapeBarHide = true
	ShapeshiftBarFrame:Hide()
	BarKeepShapeFrame:Hide()
	BarKeepShapeDragButton:Hide()
end

function BarKeepOptions_ShowShapeBar()
	BK_Setting.ShapeBarHide = false
	if BK_Setting.Locked then
		BarKeepShapeDragButton:Hide()
	else
		BarKeepShapeDragButton:Show()
	end
	ShapeshiftBarFrame:Show()
	BarKeepShapeFrame:Show()
end

function BarKeepOptions_HideMenuBar()
	BK_Setting.MenuBarHide = true
	BarKeepOptions_UpdateState()
end

function BarKeepOptions_ShowMenuBar()
	BK_Setting.MenuBarHide = false
	BarKeepOptions_UpdateState()
end

function BarKeepOptions_Lock()
	BK_Setting.Locked = true
	BarKeepOptions_UpdateState()
end

function BarKeepOptions_UnLock()
	BK_Setting.Locked = false
	BarKeepOptions_UpdateState()
end

function BarKeepOptions_ShowButtons(buttonbar)
	for i = 1,12,1 do
		local button=_G[buttonbar..i]
		button:SetAlpha(1)
		button:Show()
		ActionButton_Update (button)
	end
end
